==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_info.js <==
var struct_data_provider_1_1_data_provider_info =
[
    [ "add_field_options", "struct_data_provider_1_1_data_provider_info.html#a0c360c36933d1349b1b25dc29256b1f3", null ],
    [ "child_create_options", "struct_data_provider_1_1_data_provider_info.html#a752a616529b0d85ede6e520f58dece8b", null ],
    [ "child_delete_options", "struct_data_provider_1_1_data_provider_info.html#a3e74c9131351257c1f9435b9c8e9965a", null ],
    [ "children", "struct_data_provider_1_1_data_provider_info.html#ab4c13f2df213c9cd99e90d2c5f1e5d40", null ],
    [ "children_can_support_apis", "struct_data_provider_1_1_data_provider_info.html#ac2ffaeafa5e87ddba43137e7947d1444", null ],
    [ "children_can_support_messages", "struct_data_provider_1_1_data_provider_info.html#a65bcf11fcff466fc6f4f1316523825a4", null ],
    [ "children_can_support_observers", "struct_data_provider_1_1_data_provider_info.html#a20bf218e9885012826d5dbd30a60573d", null ],
    [ "children_can_support_records", "struct_data_provider_1_1_data_provider_info.html#ac8dfdf322cddb323ac4e3adf91806a48", null ],
    [ "children_can_support_transactions", "struct_data_provider_1_1_data_provider_info.html#aebefd0db68b65e2d705ebc5692945e0d", null ],
    [ "constructor_options", "struct_data_provider_1_1_data_provider_info.html#a9b8578d70ed12ef55972c17d38f35410", null ],
    [ "create_options", "struct_data_provider_1_1_data_provider_info.html#a9e6e33aeb3955e61397c79287a6a7a5d", null ],
    [ "delete_field_options", "struct_data_provider_1_1_data_provider_info.html#ac07c145f3daaa8e7405b3710d9419df5", null ],
    [ "desc", "struct_data_provider_1_1_data_provider_info.html#adc3381f78eea899e4c7c9983fa654922", null ],
    [ "events", "struct_data_provider_1_1_data_provider_info.html#a075ce1412ac66415c025d377230f55ba", null ],
    [ "expressions", "struct_data_provider_1_1_data_provider_info.html#a1b627116aab7c4527f4f3e59e14a8c5d", null ],
    [ "has_record", "struct_data_provider_1_1_data_provider_info.html#afb1c6af92a1a848733b5dcae214986c6", null ],
    [ "mapper_keys", "struct_data_provider_1_1_data_provider_info.html#a78d08fa3c961f677293318f2f482c1d7", null ],
    [ "messages", "struct_data_provider_1_1_data_provider_info.html#a0dc8d29dfd686a471374b74a657d409f", null ],
    [ "name", "struct_data_provider_1_1_data_provider_info.html#a59faa103679df01e9e501de63472d39e", null ],
    [ "record_requires_search_options", "struct_data_provider_1_1_data_provider_info.html#a8664b380bead15fdb3582b8f7e0767dc", null ],
    [ "request_options", "struct_data_provider_1_1_data_provider_info.html#a4ef503043dde9ad5921fb1d31dc84f8d", null ],
    [ "schema_type", "struct_data_provider_1_1_data_provider_info.html#af63cb50938a573bf4f4a4532ba3a9354", null ],
    [ "search_logic_capabilities", "struct_data_provider_1_1_data_provider_info.html#af3510c9097c8b51f3741eef08e0b1e5e", null ],
    [ "search_options", "struct_data_provider_1_1_data_provider_info.html#a558497c0cbd189290573fc58142ec544", null ],
    [ "send_message_options", "struct_data_provider_1_1_data_provider_info.html#ac2c2172215d2075b5ae636511146a702", null ],
    [ "supports_add_field", "struct_data_provider_1_1_data_provider_info.html#a5d8320604f5f3de063c25ea673c6ccf4", null ],
    [ "supports_bulk_create", "struct_data_provider_1_1_data_provider_info.html#abfca9615ebec881841d9ee1127d041dc", null ],
    [ "supports_bulk_read", "struct_data_provider_1_1_data_provider_info.html#a0bc7b0b204e71d0304a7f7879cd8deb4", null ],
    [ "supports_bulk_upsert", "struct_data_provider_1_1_data_provider_info.html#a6d803adbbba3aebfc6e4ff21e7b96e92", null ],
    [ "supports_child_create", "struct_data_provider_1_1_data_provider_info.html#a3dba477d9171000010a710bad7ae6e92", null ],
    [ "supports_child_delete", "struct_data_provider_1_1_data_provider_info.html#a28cbf660bd62270fcdc7dd13c33d6aea", null ],
    [ "supports_children", "struct_data_provider_1_1_data_provider_info.html#ac2d3daf465ad7b27a78ffd57072ebb82", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_info.html#aa861609325bdc140c3df5ade56f148cc", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_info.html#a03365ab8ee7965f0a04779a658a4fd45", null ],
    [ "supports_delete_field", "struct_data_provider_1_1_data_provider_info.html#a370e3e1f67e34256f4fc96d757012ae1", null ],
    [ "supports_messages", "struct_data_provider_1_1_data_provider_info.html#a01bef5cb44aece69e03298cf77d07291", null ],
    [ "supports_native_search", "struct_data_provider_1_1_data_provider_info.html#a412061810da94fa2cb02b310cebc6cf9", null ],
    [ "supports_observable", "struct_data_provider_1_1_data_provider_info.html#ab641588bde2dfb14325f93d5e72c194e", null ],
    [ "supports_read", "struct_data_provider_1_1_data_provider_info.html#a82f69a9926a237125d3c12482647c404", null ],
    [ "supports_request", "struct_data_provider_1_1_data_provider_info.html#a92c8bec23b5baecd32d0a27c640859e1", null ],
    [ "supports_schema", "struct_data_provider_1_1_data_provider_info.html#ae9a9bd29af4c27233fccaa9fc7d4b924", null ],
    [ "supports_search_expressions", "struct_data_provider_1_1_data_provider_info.html#a8d873e9d25f7ed6e0dfb1d956a0557c8", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_info.html#a8add15abae4ec692dea441ffafe189f7", null ],
    [ "supports_update_field", "struct_data_provider_1_1_data_provider_info.html#a9226d33657b357f745887d1eac834aed", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_info.html#abecd5865cd94dbaed26069cc83a5fc09", null ],
    [ "transaction_management", "struct_data_provider_1_1_data_provider_info.html#a1b1ffae69aed98e0eda67328abebf4c0", null ],
    [ "type", "struct_data_provider_1_1_data_provider_info.html#a35b6587734a2c9d4b9e2a8b646a7b0b5", null ],
    [ "update_field_options", "struct_data_provider_1_1_data_provider_info.html#ace544d5dd078f6284495b6ffc10e4a32", null ],
    [ "upsert_options", "struct_data_provider_1_1_data_provider_info.html#a8e6077cefe43b0d267526774e62ee2d7", null ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_info.js <==
var struct_data_provider_1_1_data_provider_info =
[
    [ "add_field_options", "struct_data_provider_1_1_data_provider_info.html#a0c360c36933d1349b1b25dc29256b1f3", null ],
    [ "child_create_options", "struct_data_provider_1_1_data_provider_info.html#a752a616529b0d85ede6e520f58dece8b", null ],
    [ "child_delete_options", "struct_data_provider_1_1_data_provider_info.html#a3e74c9131351257c1f9435b9c8e9965a", null ],
    [ "children", "struct_data_provider_1_1_data_provider_info.html#ab4c13f2df213c9cd99e90d2c5f1e5d40", null ],
    [ "children_can_support_apis", "struct_data_provider_1_1_data_provider_info.html#ac2ffaeafa5e87ddba43137e7947d1444", null ],
    [ "children_can_support_messages", "struct_data_provider_1_1_data_provider_info.html#a65bcf11fcff466fc6f4f1316523825a4", null ],
    [ "children_can_support_observers", "struct_data_provider_1_1_data_provider_info.html#a20bf218e9885012826d5dbd30a60573d", null ],
    [ "children_can_support_records", "struct_data_provider_1_1_data_provider_info.html#ac8dfdf322cddb323ac4e3adf91806a48", null ],
    [ "children_can_support_transactions", "struct_data_provider_1_1_data_provider_info.html#aebefd0db68b65e2d705ebc5692945e0d", null ],
    [ "children_identical", "struct_data_provider_1_1_data_provider_info.html#a4adbeca5e6e91c68851d7ef5f99f61d1", null ],
    [ "connection_event", "struct_data_provider_1_1_data_provider_info.html#ac6ccd9fdf7e397a80da42a0b6d6a5074", null ],
    [ "constructor_options", "struct_data_provider_1_1_data_provider_info.html#a9b8578d70ed12ef55972c17d38f35410", null ],
    [ "create_options", "struct_data_provider_1_1_data_provider_info.html#a9e6e33aeb3955e61397c79287a6a7a5d", null ],
    [ "delete_field_options", "struct_data_provider_1_1_data_provider_info.html#ac07c145f3daaa8e7405b3710d9419df5", null ],
    [ "desc", "struct_data_provider_1_1_data_provider_info.html#adc3381f78eea899e4c7c9983fa654922", null ],
    [ "disconnection_event", "struct_data_provider_1_1_data_provider_info.html#a790ba24a52e4bea9f86ca04f567211be", null ],
    [ "display_name", "struct_data_provider_1_1_data_provider_info.html#a1c504c4490573efbe6f5ab795ccf15af", null ],
    [ "events", "struct_data_provider_1_1_data_provider_info.html#a075ce1412ac66415c025d377230f55ba", null ],
    [ "expressions", "struct_data_provider_1_1_data_provider_info.html#a1b627116aab7c4527f4f3e59e14a8c5d", null ],
    [ "has_record", "struct_data_provider_1_1_data_provider_info.html#afb1c6af92a1a848733b5dcae214986c6", null ],
    [ "info", "struct_data_provider_1_1_data_provider_info.html#a6b310eb980ab3623e10ba9f348e3e235", null ],
    [ "mapper_keys", "struct_data_provider_1_1_data_provider_info.html#a78d08fa3c961f677293318f2f482c1d7", null ],
    [ "messages", "struct_data_provider_1_1_data_provider_info.html#a0dc8d29dfd686a471374b74a657d409f", null ],
    [ "name", "struct_data_provider_1_1_data_provider_info.html#a59faa103679df01e9e501de63472d39e", null ],
    [ "record_requires_search_options", "struct_data_provider_1_1_data_provider_info.html#a8664b380bead15fdb3582b8f7e0767dc", null ],
    [ "request_options", "struct_data_provider_1_1_data_provider_info.html#a4ef503043dde9ad5921fb1d31dc84f8d", null ],
    [ "required_constructor_options", "struct_data_provider_1_1_data_provider_info.html#a43b6afeebb0a152db47fcc888ab2253e", null ],
    [ "schema_type", "struct_data_provider_1_1_data_provider_info.html#af63cb50938a573bf4f4a4532ba3a9354", null ],
    [ "search_logic_capabilities", "struct_data_provider_1_1_data_provider_info.html#af3510c9097c8b51f3741eef08e0b1e5e", null ],
    [ "search_options", "struct_data_provider_1_1_data_provider_info.html#a558497c0cbd189290573fc58142ec544", null ],
    [ "send_message_options", "struct_data_provider_1_1_data_provider_info.html#ac2c2172215d2075b5ae636511146a702", null ],
    [ "short_desc", "struct_data_provider_1_1_data_provider_info.html#aad01a08d90a57feb52309b0ce1de2364", null ],
    [ "supports_add_field", "struct_data_provider_1_1_data_provider_info.html#a5d8320604f5f3de063c25ea673c6ccf4", null ],
    [ "supports_auto_reconnect", "struct_data_provider_1_1_data_provider_info.html#a28a63d25997b6942baef4f06ea1786ab", null ],
    [ "supports_bulk_create", "struct_data_provider_1_1_data_provider_info.html#abfca9615ebec881841d9ee1127d041dc", null ],
    [ "supports_bulk_read", "struct_data_provider_1_1_data_provider_info.html#a0bc7b0b204e71d0304a7f7879cd8deb4", null ],
    [ "supports_bulk_upsert", "struct_data_provider_1_1_data_provider_info.html#a6d803adbbba3aebfc6e4ff21e7b96e92", null ],
    [ "supports_child_create", "struct_data_provider_1_1_data_provider_info.html#a3dba477d9171000010a710bad7ae6e92", null ],
    [ "supports_child_delete", "struct_data_provider_1_1_data_provider_info.html#a28cbf660bd62270fcdc7dd13c33d6aea", null ],
    [ "supports_children", "struct_data_provider_1_1_data_provider_info.html#ac2d3daf465ad7b27a78ffd57072ebb82", null ],
    [ "supports_connections", "struct_data_provider_1_1_data_provider_info.html#a1644572470340f7ab3b6102f9a6bc298", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_info.html#aa861609325bdc140c3df5ade56f148cc", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_info.html#a03365ab8ee7965f0a04779a658a4fd45", null ],
    [ "supports_delete_field", "struct_data_provider_1_1_data_provider_info.html#a370e3e1f67e34256f4fc96d757012ae1", null ],
    [ "supports_messages", "struct_data_provider_1_1_data_provider_info.html#a01bef5cb44aece69e03298cf77d07291", null ],
    [ "supports_native_search", "struct_data_provider_1_1_data_provider_info.html#a412061810da94fa2cb02b310cebc6cf9", null ],
    [ "supports_observable", "struct_data_provider_1_1_data_provider_info.html#ab641588bde2dfb14325f93d5e72c194e", null ],
    [ "supports_read", "struct_data_provider_1_1_data_provider_info.html#a82f69a9926a237125d3c12482647c404", null ],
    [ "supports_request", "struct_data_provider_1_1_data_provider_info.html#a92c8bec23b5baecd32d0a27c640859e1", null ],
    [ "supports_schema", "struct_data_provider_1_1_data_provider_info.html#ae9a9bd29af4c27233fccaa9fc7d4b924", null ],
    [ "supports_search_expressions", "struct_data_provider_1_1_data_provider_info.html#a8d873e9d25f7ed6e0dfb1d956a0557c8", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_info.html#a8add15abae4ec692dea441ffafe189f7", null ],
    [ "supports_update_field", "struct_data_provider_1_1_data_provider_info.html#a9226d33657b357f745887d1eac834aed", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_info.html#abecd5865cd94dbaed26069cc83a5fc09", null ],
    [ "transaction_management", "struct_data_provider_1_1_data_provider_info.html#a1b1ffae69aed98e0eda67328abebf4c0", null ],
    [ "type", "struct_data_provider_1_1_data_provider_info.html#a35b6587734a2c9d4b9e2a8b646a7b0b5", null ],
    [ "update_field_options", "struct_data_provider_1_1_data_provider_info.html#ace544d5dd078f6284495b6ffc10e4a32", null ],
    [ "upsert_options", "struct_data_provider_1_1_data_provider_info.html#a8e6077cefe43b0d267526774e62ee2d7", null ]
];
